@@ -7,7 +7,7 @@ use base 'Rose::Object';
 use Scalar::Util qw(refaddr);
 use Rose::DB::Cache::Entry;
 
-our $VERSION = '0.739';
+our $VERSION = '0.745';
 
 our $Debug = 0;
 
@@ -89,6 +89,13 @@ sub db_cache_entries
                      [ values %{$self->{'cache'} || {}} ];
 }
 
+sub db_cache_keys
+{
+  my($self) = shift;
+  return wantarray ? keys %{$self->{'cache'} || {}} : 
+                     [ keys %{$self->{'cache'} || {}} ];
+}
+
 sub get_db
 {
   my($self) = shift;
@@ -314,6 +321,14 @@ name/value pairs.  Any object method is a valid parameter name.
 
 Clear the cache entirely.
 
+=item B<db_cache_entries>
+
+Returns a list (in list context) or reference to an array (in scalar context) of L<cache entries|Rose::DB::Cache::Entry> for each cached db object.
+
+=item B<db_cache_keys>
+
+Returns a list (in list context) or reference to an array (in scalar context) of L<keys|Rose::DB::Cache::Entry/key> for each L <cache entries|Rose::DB::Cache::Entry>.
+
 =item B<get_db [PARAMS]>
 
 Return the cached L<Rose::DB>-derived object corresponding to the name/value pairs passed in PARAMS.  PARAMS are passed to the L<build_cache_key|/build_cache_key> method, and the key returned is used to look up the cached object.
